.. image:: https://raw.githubusercontent.com/senaite/senaite.lims/master/static/logo_pypi.png
   :target: https://github.com/senaite/senaite.lims#readme
   :alt: senaite.lims
   :height: 128

- **SENAITE.LIMS**: *Meta Installation Package*

.. image:: https://img.shields.io/pypi/v/senaite.lims.svg?style=flat-square
   :target: https://pypi.python.org/pypi/senaite.lims

.. image:: https://img.shields.io/badge/README-GitHub-blue.svg?style=flat-square
   :target: https://github.com/senaite/senaite.lims#readme

.. image:: https://img.shields.io/badge/Built%20with-%E2%9D%A4-red.svg
   :target: https://github.com/senaite/senaite.lims

.. image:: https://img.shields.io/badge/Made%20for%20SENAITE-%E2%AC%A1-lightgrey.svg
   :target: https://www.senaite.com



License
=======

**SENAITE.LIMS** Copyright (C) `RIDING BYTES <https://ridingbytes.com>`_ & `NARALABS <https://naralabs.com>`_

This program is free software; you can redistribute it and/or modify it under
the terms of the `GNU General Public License version 2
<https://github.com/senaite/senaite.queue/blob/master/LICENSE>`_ as published
by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
